//
//  ImagePickerManager.swift
//  jm_basic_flutter
//
//  Created by HuberyYang on 2022/9/24.
//

import UIKit
import ZLPhotoBrowser
import Photos

class ImagePickerManager: NSObject {
    static func makeImagePicker(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        guard let currentVC = kRootFlutterViewController else {
            result(nil)
            return
        }
        let arguments = call.arguments as? [String:Any] ?? [:]
        let isCamera = arguments["isCamera"] as? Bool ?? false
        let config = ZLPhotoConfiguration.default()
        
        if isCamera {
            let camera = ZLCustomCamera()
            camera.takeDoneBlock = { (image, videoUrl) in
                self.save(image: image, videoUrl: videoUrl, result: result)
            }
            currentVC.showDetailViewController(camera, sender: nil)
        } else {
            let maxSelectCount = arguments["maxSelectCount"] as? Int ?? 9
            let allowSelectGif = arguments["allowSelectGif"] as? Bool ?? false
            config.maxSelectCount = maxSelectCount
            config.allowSelectGif = allowSelectGif
            config.allowSelectVideo = false
            config.allowTakePhotoInLibrary = false
            
            let ps = ZLPhotoPreviewSheet()
            ps.selectImageBlock = { (resModels, isFullImage) in
                let assets = resModels.map { m in
                    return m.asset
                }
                fetchImageLocalPath(assets, result: result)
            }
            ps.showPhotoLibrary(sender: currentVC)
        }
    }
    
    private static func fetchImageLocalPath(_ assets: [PHAsset], result: @escaping FlutterResult) {
        guard !assets.isEmpty else {
            result(nil)
            return
        }
        
        let queue = DispatchQueue(label: "fetch image local path task")
        let group = DispatchGroup()
        var imageLocalPathList: [String] = []
        
        assets.forEach { asset in
            group.enter()
            
            ZLPhotoManager.fetchAssetFilePath(asset: asset) { path in
                // flutter file 无法识别 "file:///"，所以需要移除
                var resPath = path ?? ""
                if resPath.hasPrefix("file:///") {
                    resPath = resPath.replacingOccurrences(of: "file:///", with: "")
                }
                imageLocalPathList.append(resPath)
                group.leave()
            }
        }
        
        group.notify(queue: queue) {
            kPrintLog("imageLocalPathList \(imageLocalPathList)")
            
            result(imageLocalPathList)
        }
    }
    
    private static func save(image: UIImage?, videoUrl: URL?, result: @escaping FlutterResult) {
        let hud = ZLProgressHUD(style: ZLPhotoUIConfiguration.default().hudStyle)
        if let image = image {
            hud.show()
            ZLPhotoManager.saveImageToAlbum(image: image) { suc, asset in
                if suc, let asset = asset {
                    fetchImageLocalPath([asset], result: result)
                } else {
                    result(nil)
                }
                hud.hide()
            }
        } else {
            result(nil)
        }
    }
    
}
