//
//  NetworkManager.swift
//  Runner
//
//  Created by HuberyYang on 2022/3/18.
//

import Foundation
import Alamofire

class NetworkManager: NSObject {
    
    private static func urlEncodeString(_ url: String) -> String {
        return url.addingPercentEncoding(withAllowedCharacters: CharacterSet.urlQueryAllowed) ?? url
    }
    
    static func request(data: [String: Any]?, finish: @escaping ([String: Any?]) -> Void) {
        guard let method = data?["method"] as? String,
              let urlString = data?["urlString"] as? String,
              let url = URL(string: urlEncodeString(urlString)),
              let headers = data?["headers"] as? [String: String]
        else {
            finish(["isSuccess": false, "statusCode": -1, "message": "request parameters error"])
            return
        }
        
        let parameters = data?["parameters"] as? Parameters
        AF.request(url,
                   method: HTTPMethod(rawValue: method),
                   parameters: parameters,
                   encoding: method == HTTPMethod.get.rawValue ? URLEncoding.default : JSONEncoding.default,
                   headers: HTTPHeaders(headers)).responseData { res in
            dealResponse(urlString,
                         method: method,
                         headers: headers,
                         res: res,
                         parameters: parameters,
                         finish: finish)
        }
    }
    
    fileprivate static func dealResponse(_ urlString: String,
                                         method: String,
                                         headers: [String: String],
                                         res: AFDataResponse<Data>,
                                         parameters: Parameters?,
                                         finish: @escaping ([String: Any?]) -> Void) {
        let statusCode = res.response?.statusCode ?? -1
        if let error = res.error {
            finish(["isSuccess": false, "statusCode": statusCode, "message": error.localizedDescription])
        } else {
            finish(["isSuccess": true, "statusCode": statusCode, "data": res.data])
        }
    }
    
    fileprivate static func jsonResponseDataFormatter(_ data: Data) -> String {
        do {
            let json = try JSONSerialization.jsonObject(with: data, options: [.mutableContainers, .mutableLeaves, .fragmentsAllowed])
            let jsonData = try JSONSerialization.data(withJSONObject: json, options: .prettyPrinted)
            let jsonString = String(data: jsonData, encoding: String.Encoding.utf8)
            return jsonString ?? "## Cannot map data to String ##"
        } catch {
            return "## Cannot map data to String - error: \(error.localizedDescription)  ##"
        }
    }
    
}

