import 'dart:convert';
import 'package:dio/dio.dart';
import 'package:flutter/foundation.dart';

mixin NetworkConfigMixin {
  String get baseUrl;

  String get businessPlatform;

  String get deviceSource;

  // 默认的基础请求头参数
  Map<String, String> get basicHeaders;

  // 请求头
  Map<String, String> get requestHeaders;

  // 网络请求失败提示
  String get netRequestFailedTips;

  // json 解析
  T? fromJsonAsT<T>(json);

  void iosRequestPrint(
    String method,
    String urlString,
    Map<String, String> headers, {
    dynamic parameters,
  });

  void iosResponsePrint(
    String method,
    String urlString,
    Map<String, String> headers,
    Map response, {
    dynamic parameters,
  });

  Map<String, dynamic> debugJsonParseForIos(
    Map<String, String> headers,
    String debugJson,
  ) {
    Map valueMap = json.decode(debugJson);
    var parseData = <String, dynamic>{};
    parseData['headers'] = headers;
    try {
      parseData['isSuccess'] = true;
      parseData['statusCode'] = 200;
      parseData['data'] = valueMap['data'];
    } catch (error) {
      parseData['isSuccess'] = false;
      parseData['statusCode'] = 500;
      debugPrint('debug json parse error: ${error.toString()}');
    }
    return parseData;
  }

  Response debugJsonParseForNormal(
    Map<String, String> headers,
    String path,
    String debugJson,
  ) {
    final requestOptions = RequestOptions(path: path);
    try {
      Map valueMap = json.decode(debugJson);
      return Response(
        data: valueMap,
        requestOptions: requestOptions,
        statusCode: 200,
      );
    } catch (error) {
      debugPrint('debug json parse error: ${error.toString()}');
      return Response(
        data: null,
        requestOptions: requestOptions,
        statusCode: 500,
      );
    }
  }

  // 请求失败
  void netRequestSuccess(int code, String message, String urlString);

}
