import 'package:flutter/material.dart';

class BothSideTextCell extends StatelessWidget {
  final double space;
  final EdgeInsetsGeometry padding;
  final String title;
  final String content;
  final TextStyle titleStyle;
  final TextStyle contentStyle;
  final int titleMaxLines;
  final int contentMaxLines;
  final bool canTitleExpanded;
  final Color dividerColor;

  const BothSideTextCell({
    Key? key,
    this.space = 12,
    this.padding = const EdgeInsets.all(0),
    this.title = '',
    this.content = '',
    this.titleStyle = const TextStyle(color: Color(0xFF777777), fontSize: 14, fontWeight: FontWeight.normal),
    this.contentStyle = const TextStyle(color: Color(0xFF777777), fontSize: 14, fontWeight: FontWeight.normal),
    this.titleMaxLines = 1,
    this.contentMaxLines = 1,
    this.canTitleExpanded = true,
    this.dividerColor = Colors.transparent,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: padding,
      child: Row(children: [
        Visibility(
          visible: canTitleExpanded,
          replacement: Text(title, style: titleStyle, overflow: TextOverflow.ellipsis, maxLines: titleMaxLines, textAlign: TextAlign.left),
          child: Expanded(
            child: Text(title, style: titleStyle, overflow: TextOverflow.ellipsis, maxLines: titleMaxLines, textAlign: TextAlign.left),
          ),
        ),
        VerticalDivider(width: space, color: dividerColor),
        Expanded(
          child: Text(content, style: contentStyle, overflow: TextOverflow.ellipsis, maxLines: contentMaxLines, textAlign: TextAlign.right),
        ),
      ]),
    );
  }
}
