import 'package:flutter/material.dart';

// 连点手势
class ContinuousTapGestureDetector extends GestureDetector {
  final Widget gestureChild;
  final ContinuousTapListener listener; // 连点监听者

  ContinuousTapGestureDetector({
    required this.gestureChild,
    required this.listener,
  }) : super(
            child: gestureChild,
            onTap: () {
              listener.onTapListening();
            });
}

class ContinuousTapListener {
  final int numberOfTapsRequired; // 需要连点的次数， 默认为 1 次
  final int maxMillisecondsBetweenTwoTaps; // 两次点击的允许的最大时间间隔(毫秒)
  final void Function()? onContinuousTap; // 满足连点条件时的回调

  int _lastTapTime = 0; // 上一次点击的时间戳
  int _numberOfTapRecorded = 0; // 已记录的点击次数

  ContinuousTapListener({
    this.numberOfTapsRequired = 1,
    this.maxMillisecondsBetweenTwoTaps = 500,
    this.onContinuousTap,
  });

  void onTapListening() {
    final now = DateTime.now().millisecondsSinceEpoch;
    if (_lastTapTime > 0 && now - _lastTapTime > maxMillisecondsBetweenTwoTaps) {
      _record(time: now, count: 1);
    } else {
      _record(time: now, count: _numberOfTapRecorded + 1);
      _checkAvailable();
    }
  }

  // 记录
  void _record({int time = 0, int count = 0}) {
    _lastTapTime = time;
    _numberOfTapRecorded = count;
  }

  // 验证是否满足预设条件，如果满足则执行回调函数
  void _checkAvailable() {
    if (_numberOfTapRecorded >= numberOfTapsRequired) {
      _record();
      if (onContinuousTap != null) {
        onContinuousTap!();
      }
    }
  }
}