import 'package:flutter/material.dart';

// 图标与文本相对位置
enum IconTextButtonRelativePosition {
  iconTop,
  iconLeft,
  iconRight,
  iconBottom
}

// 图文按钮
class IconTextButton extends StatelessWidget {
  final IconTextButtonRelativePosition relativePosition;
  final EdgeInsetsGeometry margin;
  final EdgeInsetsGeometry padding;
  final double space;
  final Color backgroundColor;
  final Decoration? decoration;
  final MainAxisAlignment mainAxisAlignment;
  final MainAxisSize mainAxisSize;
  final CrossAxisAlignment crossAxisAlignment;
  final TextDirection? textDirection;
  final VerticalDirection verticalDirection;
  final Widget label;
  final Widget icon;
  final VoidCallback? onPressed;

  const IconTextButton({
    Key? key,
    this.relativePosition = IconTextButtonRelativePosition.iconRight,
    this.margin = EdgeInsets.zero,
    this.padding = EdgeInsets.zero,
    this.space = 2,
    this.backgroundColor = Colors.transparent,
    this.decoration,
    this.mainAxisAlignment = MainAxisAlignment.start,
    this.mainAxisSize = MainAxisSize.max,
    this.crossAxisAlignment = CrossAxisAlignment.center,
    this.textDirection,
    this.verticalDirection = VerticalDirection.down,
    required this.label,
    required this.icon,
    this.onPressed,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: onPressed,
      child: Container(
        margin: margin,
        padding: padding,
        color: decoration != null ? null : backgroundColor,
        decoration: decoration,
        child: _addSubWidgets(),
      ),
    );
  }

  Widget _addSubWidgets() {
    switch (relativePosition) {
      case IconTextButtonRelativePosition.iconTop:
        return Column(
          mainAxisAlignment: mainAxisAlignment,
          mainAxisSize: mainAxisSize,
          crossAxisAlignment: crossAxisAlignment,
          textDirection: textDirection,
          verticalDirection: verticalDirection,
          children: [
            icon,
            Divider(height: space, color: Colors.transparent),
            label
          ],
        );

      case IconTextButtonRelativePosition.iconLeft:
        return Row(
          mainAxisAlignment: mainAxisAlignment,
          mainAxisSize: mainAxisSize,
          crossAxisAlignment: crossAxisAlignment,
          textDirection: textDirection,
          verticalDirection: verticalDirection,
          children: [
            icon,
            VerticalDivider(width: space, color: Colors.transparent),
            label
          ],
        );

      case IconTextButtonRelativePosition.iconRight:
        return Row(
          mainAxisAlignment: mainAxisAlignment,
          mainAxisSize: mainAxisSize,
          crossAxisAlignment: crossAxisAlignment,
          textDirection: textDirection,
          verticalDirection: verticalDirection,
          children: [
            label,
            VerticalDivider(width: space, color: Colors.transparent),
            icon
          ],
        );

      case IconTextButtonRelativePosition.iconBottom:
        return Column(
          mainAxisAlignment: mainAxisAlignment,
          mainAxisSize: mainAxisSize,
          crossAxisAlignment: crossAxisAlignment,
          textDirection: textDirection,
          verticalDirection: verticalDirection,
          children: [
            label,
            Divider(height: space, color: Colors.transparent),
            icon
          ],
        );

      default:
        return Container(color: Colors.transparent);
    }
  }
}